def hello_world():
    # [REQ-001]
    print("Hello world!")  # noqa: T201
    # [/REQ-001]
